package com.ruoyi.mall.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.mall.domain.MallBatchDetail;

/**
 * 批次说明Service接口
 *
 * @author lsm
 * @date 2023-10-19
 */
public interface IMallBatchDetailService
{
    /**
     * 查询批次说明
     *
     * @param batchDetailId 批次说明主键
     * @return 批次说明
     */
    public MallBatchDetail selectMallBatchDetailByBatchDetailId(Long batchDetailId);

    /**
     * 查询批次说明列表
     *
     * @param mallBatchDetail 批次说明
     * @return 批次说明集合
     */
    public List<MallBatchDetail> selectMallBatchDetailList(MallBatchDetail mallBatchDetail);

    /**
     * 新增批次说明
     *
     * @param mallBatchDetail 批次说明
     * @return 结果
     */
    public int insertMallBatchDetail(MallBatchDetail mallBatchDetail);

    /**
     * 修改批次说明
     *
     * @param mallBatchDetail 批次说明
     * @return 结果
     */
    public int updateMallBatchDetail(MallBatchDetail mallBatchDetail);

    /**
     * 批量删除批次说明
     *
     * @param batchDetailIds 需要删除的批次说明主键集合
     * @return 结果
     */
    public int deleteMallBatchDetailByBatchDetailIds(Long[] batchDetailIds);

    /**
     * 删除批次说明信息
     *
     * @param batchDetailId 批次说明主键
     * @return 结果
     */
    public int deleteMallBatchDetailByBatchDetailId(Long batchDetailId);

    /**
     * 批次说明
     * @return 结果
     */
    public AjaxResult selectBatchDetailList();
}
